Package: aroma.affymetrix
Version: 3.2.3
Depends: R (>= 3.2.0), R.utils (>= 2.9.0), aroma.core (>= 3.2.0)
Imports: methods, R.methodsS3 (>= 1.7.1), R.oo (>= 1.23.0), R.cache (>=
        0.14.0), R.devices (>= 2.16.1), R.filesets (>= 2.13.0),
        aroma.apd (>= 0.6.0), MASS, splines, matrixStats (>= 0.55.0),
        listenv, future
Suggests: DBI (>= 1.0.0), RColorBrewer (>= 1.1-2), Biobase (>= 2.28.0),
        BiocGenerics (>= 0.14.0), affxparser (>= 1.40.0), affy (>=
        1.46.0), affyPLM (>= 1.44.0), aroma.light (>= 2.4.0), gcrma (>=
        2.40.0), limma (>= 3.24.1), oligo (>= 1.32.0), oligoClasses (>=
        1.30.0), pdInfoBuilder (>= 1.32.0), preprocessCore (>= 1.28.0),
        AffymetrixDataTestFiles, dChipIO (>= 0.1.1)
SuggestsNote: BioC (>= 3.0), Recommended: preprocessCore, affyPLM,
        aroma.light, affxparser, DNAcopy
Title: Analysis of Large Affymetrix Microarray Data Sets
Authors@R: c(
  person("Henrik", "Bengtsson", role=c("aut", "cre", "cph"),
                                 email="henrikb@braju.com"),
  person("James", "Bullard", role="ctb"),
  person("Kasper", "Hansen", role="ctb"),
  person("Pierre", "Neuvial", role="ctb"),
  person("Elizabeth", "Purdom", role="ctb"),
  person("Mark", "Robinson", role="ctb"),
  person("Ken", "Simpson", role="ctb"))
Description: A cross-platform R framework that facilitates processing of any number of Affymetrix microarray samples regardless of computer system.  The only parameter that limits the number of chips that can be processed is the amount of available disk space.  The Aroma Framework has successfully been used in studies to process tens of thousands of arrays.  This package has actively been used since 2006.
License: LGPL (>= 2.1)
URL: https://www.aroma-project.org/,
        https://github.com/HenrikBengtsson/aroma.affymetrix
BugReports: https://github.com/HenrikBengtsson/aroma.affymetrix/issues
LazyLoad: TRUE
biocViews: Infrastructure, ProprietaryPlatforms, ExonArray, Microarray,
        OneChannel, GUI, DataImport, DataRepresentation, Preprocessing,
        QualityControl, Visualization, ReportWriting, aCGH,
        CopyNumberVariants, DifferentialExpression, GeneExpression,
        SNP, Transcription
NeedsCompilation: no
Packaged: 2025-08-19 03:09:09 UTC; hb
Author: Henrik Bengtsson [aut, cre, cph],
  James Bullard [ctb],
  Kasper Hansen [ctb],
  Pierre Neuvial [ctb],
  Elizabeth Purdom [ctb],
  Mark Robinson [ctb],
  Ken Simpson [ctb]
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2025-08-19 07:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 19:45:22 UTC; unix
