# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# IMPORTS
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
importFrom("R.oo", "throw")
importFrom("R.methodsS3", "setMethodS3")
importFrom("R.oo", "setConstructorS3")
importFrom("R.oo", "extend")
importFrom("R.oo", "uses")

## Importing Class:es
importFrom("R.oo", "Class")
importFrom("R.oo", "Interface")
importFrom("R.oo", "Object")
importFrom("R.oo", "Package")
importFrom("R.utils", "GenericSummary")
importFrom("R.utils", "Options")
importFrom("R.utils", "ProgressBar")
importFrom("R.filesets", "getChecksumFile")
importFrom("R.filesets", "getChecksumFileSet")
importFrom("R.filesets", "GenericDataFile")
importFrom("R.filesets", "GenericDataFileSet")
importFrom("R.filesets", "TabularTextFile")
importFrom("aroma.core", "AromaCellPositionFile")
importFrom("aroma.core", "AromaCellSequenceFile")
importFrom("aroma.core", "AromaCellTabularBinaryFile")
importFrom("aroma.core", "AromaMicroarrayDataFile")
importFrom("aroma.core", "AromaMicroarrayDataSet")
importFrom("aroma.core", "AromaMicroarrayDataSetTuple")
importFrom("aroma.core", "AromaPackage")
importFrom("aroma.core", "AromaPlatform")
importFrom("aroma.core", "AromaTransform")
importFrom("aroma.core", "AromaUflFile")
importFrom("aroma.core", "AromaUgcFile")
importFrom("aroma.core", "AromaUgpFile")
importFrom("aroma.core", "AromaUnitGenotypeCallFile")
importFrom("aroma.core", "AromaUnitGenotypeCallSet")
importFrom("aroma.core", "AromaUnitSignalBinaryFile")
importFrom("aroma.core", "AromaUnitSignalBinarySet")
importFrom("aroma.core", "AromaUnitTabularBinaryFile")
importFrom("aroma.core", "AromaUnitTotalCnBinaryFile")
importFrom("aroma.core", "AromaUnitTotalCnBinarySet")
importFrom("aroma.core", "AromaUnitFracBCnBinaryFile")
importFrom("aroma.core", "AromaUnitFracBCnBinarySet")
importFrom("aroma.core", "ChromosomalModel")
importFrom("aroma.core", "Explorer")
importFrom("aroma.core", "SampleAnnotationSet")

## Importing generics
importFrom("aroma.core", "allocate")
importFrom("aroma.core", "as.CopyNumberDataSetTuple")
importFrom("aroma.core", "byChipType")
importFrom("aroma.core", "exportTotalCnRatioSet")
importFrom("aroma.core", "findByChipType")
importFrom("aroma.core", "findUnitsTodo")
importFrom("aroma.core", "fit")
importFrom("aroma.core", "fixSearchPath")
importFrom("aroma.core", "getAlias")
importFrom("aroma.core", "getAM")
importFrom("aroma.core", "getAromaUflFile")
importFrom("aroma.core", "getAromaUgpFile")
importFrom("aroma.core", "getArraysOfInput")
importFrom("aroma.core", "getAverageFile")
importFrom("aroma.core", "getChipType")
importFrom("aroma.core", "getChromosomes")
importFrom("aroma.core", "getDefaultExtension")
importFrom("aroma.core", "getExpectedOutputFullnames")
importFrom("aroma.core", "getImage")
importFrom("aroma.core", "getInputDataSet")
importFrom("aroma.core", "getListOfUnitNamesFiles")
importFrom("aroma.core", "getListOfUnitTypesFiles")
importFrom("aroma.core", "getMainPath")
importFrom("aroma.core", "getNameOfInput")
importFrom("aroma.core", "getNumberOfFilesAveraged")
importFrom("aroma.core", "getOutputDataSet")
importFrom("aroma.core", "getOutputFiles")
importFrom("aroma.core", "getParameters")
importFrom("aroma.core", "getPlatform")
importFrom("aroma.core", "getPloidy")
importFrom("aroma.core", "getPositions")
importFrom("aroma.core", "getReference")
importFrom("aroma.core", "getRegions")
importFrom("aroma.core", "getRootPath")
importFrom("aroma.core", "getSetTuple")
importFrom("aroma.core", "getTagsOfInput")
importFrom("aroma.core", "getUnitNames")
importFrom("aroma.core", "getUnitNamesFile")
importFrom("aroma.core", "getUnitsOnChromosome")
importFrom("aroma.core", "getUnitsOnChromosomes")
importFrom("aroma.core", "getUnitTypes")
importFrom("aroma.core", "getUnitTypesFile")
importFrom("aroma.core", "getWeights")
importFrom("aroma.core", "getXAM")
importFrom("aroma.core", "hasAlleleBFractions")
importFrom("aroma.core", "hasStrandiness")
importFrom("aroma.core", "importFrom")
importFrom("aroma.core", "importFromGenericTabularFile")
importFrom("aroma.core", "isMissing")
importFrom("aroma.core", "nbrOfArrays")
importFrom("aroma.core", "nbrOfCells")
importFrom("aroma.core", "nbrOfChipTypes")
importFrom("aroma.core", "nbrOfEnzymes")
importFrom("aroma.core", "nbrOfUnits")
importFrom("aroma.core", "process")
importFrom("aroma.core", "readHeader")
importFrom("aroma.core", "rescale")
importFrom("aroma.core", "setAlias")
importFrom("aroma.core", "setArrays")
importFrom("aroma.core", "setReference")
importFrom("aroma.core", "setup")
importFrom("aroma.core", "stextChipType")
importFrom("aroma.core", "updateSetupExplorerFile")
importFrom("aroma.core", "writeImage")
importFrom("aroma.core", "writeRegions")
importFrom("R.filesets", "byName")
importFrom("R.filesets", "byPath")
importFrom("R.filesets", "extractMatrix")
importFrom("R.filesets", "findByName")
importFrom("R.filesets", "fromFile")
importFrom("R.filesets", "getAsteriskTags")
importFrom("R.filesets", "getAttribute")
importFrom("R.filesets", "getColumnNames")
importFrom("R.filesets", "getDefaultColumnNames")
importFrom("R.filesets", "getDefaultFullName")
importFrom("R.filesets", "getExtensionPattern")
importFrom("R.filesets", "getFileClass")
importFrom("R.filesets", "getFilenameExtension")
importFrom("R.filesets", "getFullName")
importFrom("R.filesets", "getFullNames")
importFrom("R.filesets", "getHeader")
importFrom("R.filesets", "getReadArguments")
importFrom("R.filesets", "getTags")
importFrom("R.filesets", "hasColumnHeader")
importFrom("R.filesets", "nbrOfColumns")
importFrom("R.filesets", "nbrOfRows")
importFrom("R.filesets", "readDataFrame")
importFrom("R.filesets", "setTags")
importFrom("R.filesets", "translateColumnNames")
importFrom("R.filesets", "translateFullName")
importFrom("R.filesets", "update2")
importFrom("R.filesets", "verify")
importFrom("R.oo", "clearCache") ## Multi-sources: R.oo, R.cache, R.filesets
importFrom("R.oo", "clone") ## Multi-sources: R.oo, R.filesets, oligoClasses
importFrom("R.oo", "getCalls")
importFrom("R.oo", "getFields")
importFrom("R.oo", "getName") ## Multi-sources: R.oo, R.filesets
importFrom("R.oo", "getPath") ## Multi-sources: R.oo, R.filesets
importFrom("R.oo", "getPosition")
importFrom("R.utils", "getLabel")
importFrom("R.utils", "setLabel")
importFrom("R.utils", "validate") ## Multi-sources: R.utils, R.filesets

## Importing functions
importFrom("aroma.apd", "readApd")
importFrom("aroma.apd", "writeApd")
importFrom("aroma.core", "allocateFromUnitNamesFile")
importFrom("aroma.core", "backtransformGenotypeCone")
importFrom("aroma.core", "backtransformMultiDimensionalCone")
importFrom("aroma.core", "countBases")
importFrom("aroma.core", "display")
importFrom("aroma.core", "extractGenotypes")
importFrom("aroma.core", "findAnnotationDataByChipType")
importFrom("aroma.core", "findPngDevice")
importFrom("aroma.core", "fitGenotypeCone")
importFrom("aroma.core", "fitMultiDimensionalCone")
importFrom("aroma.core", "fitSplineBlockPolish")
importFrom("aroma.core", "fitWHLAPLM.matrix")
importFrom("aroma.core", "fixSearchPathInternal")
importFrom("aroma.core", "getArrays")
importFrom("aroma.core", "getCacheKey")
importFrom("aroma.core", "getChipTypes")
importFrom("aroma.core", "getDataFileMatrix")
importFrom("aroma.core", "getParametersAsString")
importFrom("aroma.core", "getParentPath")
importFrom("aroma.core", "getProbeLength")
importFrom("aroma.core", "getProbePositionEffectDesignMatrix")
importFrom("aroma.core", "getRam")
importFrom("aroma.core", "getReferenceSetTuple")
importFrom("aroma.core", "getTableOfArrays")
importFrom("aroma.core", "getUnitsAt")
importFrom("aroma.core", "groupBySnpNucleotides")
importFrom("aroma.core", "isAverageFile")
importFrom("aroma.core", "isHeterozygous")
importFrom("aroma.core", "lapplyInChunks")
importFrom("aroma.core", "locallyUnique")
importFrom("aroma.core", "mergeBoxplotStats")
importFrom("aroma.core", "processTime")
importFrom("aroma.core", "readFooter")
importFrom("aroma.core", "readSequenceMatrix")
importFrom("aroma.core", "readTargetStrands")
importFrom("aroma.core", "smoothWRMA")
importFrom("aroma.core", "smoothWSA")
importFrom("aroma.core", "splitInChunks")
importFrom("aroma.core", "stextLabels")
importFrom("aroma.core", "stextSize")
importFrom("aroma.core", "updateGenotypes")
importFrom("aroma.core", "updateSequenceMatrix")
importFrom("aroma.core", "updateSequences")
importFrom("aroma.core", "updateTargetStrands")
importFrom("aroma.core", "writeFooter")
importFrom("matrixStats", "colMaxs")
importFrom("matrixStats", "colMedians")
importFrom("matrixStats", "colQuantiles")
importFrom("matrixStats", "indexByRow")
importFrom("matrixStats", "colAlls")
importFrom("matrixStats", "rowAnys")
importFrom("matrixStats", "rowMads")
importFrom("matrixStats", "rowMedians") ## Multi-sources: matrixStats, Biobase
importFrom("matrixStats", "rowSds")
importFrom("matrixStats", "rowSums2")
importFrom("methods", "new")
importFrom("R.cache", "getChecksum") ## Multi-sources: R.cache, R.filesets
importFrom("R.cache", "loadCache")
importFrom("R.cache", "saveCache")
importFrom("R.devices", "devDone")
importFrom("R.filesets", "copyTo")
importFrom("R.filesets", "dropRootPathTags")
importFrom("R.filesets", "getFile")
importFrom("R.filesets", "getFiles")
importFrom("R.filesets", "getFileSize")
importFrom("R.filesets", "getNames")
importFrom("R.filesets", "getOneFile")
importFrom("R.filesets", "getPathname")
importFrom("R.filesets", "getPathnames")
importFrom("R.filesets", "getSets")
importFrom("R.filesets", "hasTag")
importFrom("R.filesets", "indexOf")
importFrom("R.filesets", "readColumns")
importFrom("R.filesets", "readRawHeader")
importFrom("R.filesets", "renameTo")
importFrom("R.filesets", "setAttributesBy")
importFrom("R.filesets", "setAttributesByTags")
importFrom("R.methodsS3", "appendVarArgs")
importFrom("R.oo", "attachLocally")
importFrom("R.oo", "equals")
importFrom("R.oo", "getDate")
importFrom("R.oo", "getEnvironment")
importFrom("R.oo", "getKnownSubclasses")
importFrom("R.oo", "getVersion")
importFrom("R.oo", "isAbstract")
importFrom("R.oo", "isOlderThan")
importFrom("R.oo", "isVisible")
importFrom("R.oo", "ll")
importFrom("R.oo", "newInstance")
importFrom("R.oo", "objectSize")
importFrom("R.oo", "startupMessage")
importFrom("R.oo", "trim")
importFrom("R.utils", "callHooks")
importFrom("R.utils", "capitalize")
importFrom("R.utils", "capture")
importFrom("R.utils", "cat") ## Multi-sources: R.utils, base
importFrom("R.utils", "createLink")
importFrom("R.utils", "dataFrame")
importFrom("R.utils", "dimNA<-")
importFrom("R.utils", "doCall")
importFrom("R.utils", "enter")
importFrom("R.utils", "exit")
importFrom("R.utils", "extract") ## Multi-sources: R.utils, R.filesets
importFrom("R.utils", "filePath")
importFrom("R.utils", "findFiles") ## Multi-sources: R.utils, affxparser
importFrom("R.utils", "getFilename") ## Multi-sources: R.utils, R.filesets
importFrom("R.utils", "getLeaves")
importFrom("R.utils", "getOption") ## Multi-sources: R.utils, base
importFrom("R.utils", "getParent")
importFrom("R.utils", "getThreshold")
importFrom("R.utils", "hasOption")
importFrom("R.utils", "hpaste")
importFrom("R.utils", "hsize")
importFrom("R.utils", "increase")
importFrom("R.utils", "insert")
importFrom("R.utils", "isDirectory")
importFrom("R.utils", "isDone")
importFrom("R.utils", "isFile") ## Multi-sources: R.utils, R.filesets
importFrom("R.utils", "isPackageInstalled")
importFrom("R.utils", "isPackageLoaded") ## Multi-sources: R.utils, oligoClasses
importFrom("R.utils", "isZero")
importFrom("R.utils", "less")
importFrom("R.utils", "loadObject")
importFrom("R.utils", "loadToEnv")
importFrom("R.utils", "more")
importFrom("R.utils", "moveInSearchPath")
importFrom("R.utils", "popState")
importFrom("R.utils", "popTemporaryFile")
importFrom("R.utils", "printf")
importFrom("R.utils", "pushState")
importFrom("R.utils", "pushTemporaryFile")
importFrom("R.utils", "readTable")
importFrom("R.utils", "reset")
importFrom("R.utils", "saveObject")
importFrom("R.utils", "seqToHumanReadable")
importFrom("R.utils", "setOption")
importFrom("R.utils", "stext")
importFrom("R.utils", "subplots")
importFrom("R.utils", "toAsciiRegExprPattern")
importFrom("R.utils", "toCamelCase")
importFrom("R.utils", "wrap")
importFrom("R.utils", "writeRaw")
importFrom("R.utils", "CmdArgsFunction")

## Manually adjusted
## Cannot import explicitly from 'base';
## importFrom("base", "parse") ## Multi-sources: R.utils, R.rsp, base
## importFrom("base", "readLines") ## Multi-sources: R.filesets, base
## importFrom("base", "gc") ## Multi-sources: R.oo, base
## importFrom("base", "warnings") ## Multi-sources: R.utils, base

## Importing other objects
importFrom("aroma.core", "aromaSettings")

## Manual imports
importFrom("R.utils", "Arguments")
importFrom("R.filesets", "append")

importFrom("grDevices",
           "boxplot.stats", "col2rgb", "gray.colors", "rainbow")

importFrom("graphics",
           "abline", "axis", "box", "bxp", "image", "layout", "lines",
           "mtext", "par", "plot", "points", "smoothScatter", "text")

importFrom("methods", "as")

importFrom("stats",
           "approx", "coef", "coefficients", "density",
           "dnorm", "glm", "lm", "lowess", "mad", "median",
           "medpolish", "na.omit", "predict", "quantile", "residuals",
           "rnorm", "sd", "smooth.spline", "t.test", "var")

importFrom("utils",
           "capture.output", "compareVersion", "data", "head",
           "object.size", "packageDescription", "packageVersion",
           "read.table", "str", "tail", "write.table")

importFrom("listenv", "listenv")
importFrom("future", "%<-%")

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Several packages are only optional or suggested for now, so
# we cannot assume they are available for import.
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
if (FALSE) {
  importFrom("aroma.light", "calibrateMultiscan")
  importFrom("aroma.light", "normalizeFragmentLength")
  importFrom("aroma.light", "normalizeQuantileSpline")
  importFrom("aroma.light", "robustSmoothSpline")

  importFrom("Biobase", "annotation") ## Multi-sources: Biobase, oligo, oligoClasses
  importFrom("Biobase", "annotation<-")
  importFrom("Biobase", "assayData")
  importFrom("Biobase", "featureNames<-")
  importFrom("Biobase", "phenoData<-")
  importFrom("Biobase", "sampleNames<-") ## Multi-sources: Biobase, oligoClasses

  importFrom("affxparser", "applyCdfGroups")
  importFrom("affxparser", "cdfHeaderToCelHeader")
  importFrom("affxparser", "cdfMergeAlleles")
  importFrom("affxparser", "compareCdfs")
  importFrom("affxparser", "convertCdf")
  importFrom("affxparser", "convertCel")
  importFrom("affxparser", "createCel")
  importFrom("affxparser", "findCdf")
  importFrom("affxparser", "invertMap")
  importFrom("affxparser", "readBpmap")
  importFrom("affxparser", "readBpmapHeader")
  importFrom("affxparser", "readCcg")
  importFrom("affxparser", "readCcgHeader")
  importFrom("affxparser", "readCdf")
  importFrom("affxparser", "readCdfCellIndices")
  importFrom("affxparser", "readCdfGroupNames")
  importFrom("affxparser", "readCdfHeader")
  importFrom("affxparser", "readCdfIsPm")
  importFrom("affxparser", "readCdfNbrOfCellsPerUnitGroup")
  importFrom("affxparser", "readCdfQc")
  importFrom("affxparser", "readCdfUnitNames")
  importFrom("affxparser", "readCdfUnits")
  importFrom("affxparser", "readCel")
  importFrom("affxparser", "readCelHeader")
  importFrom("affxparser", "readCelRectangle")
  importFrom("affxparser", "readCelUnits")
  importFrom("affxparser", "readPgfEnv")
  importFrom("affxparser", "readPgfHeader")
  importFrom("affxparser", "updateCel")
  importFrom("affxparser", "updateCelUnits")
  importFrom("affxparser", "writeCdfHeader")
  importFrom("affxparser", "writeCdfQcUnits")
  importFrom("affxparser", "writeCdfUnits")

  importFrom("affy", "bg.adjust")
  importFrom("affy", "cleancdfname")
  importFrom("affy", "close") ## Multi-sources: affy, oligoClasses, base
  importFrom("affy", "featureNames") ## Multi-sources: affy, Biobase
  importFrom("affy", "fit.li.wong")
  importFrom("affy", "image") ## Multi-sources: affy, oligo

  importFrom("affyPLM", "summary") ## Multi-sources: affyPLM, DBI, base

  importFrom("oligo", "cleanPlatformName")
  importFrom("oligo", "coef")
  importFrom("oligo", "db") ## Multi-sources: oligo, oligoClasses
  importFrom("oligo", "geometry") ## Multi-sources: oligo, oligoClasses
  importFrom("oligo", "getPlatformDesign")
  importFrom("oligo", "ncol") ## Multi-sources: oligo, base
  importFrom("oligo", "read.celfiles")
  importFrom("oligo", "residuals")

  importFrom("oligoClasses", "getM")
  importFrom("oligoClasses", "mean") ## Multi-sources: oligoClasses, base

  importFrom("DBI", "dbGetQuery")
  importFrom("DBI", "dbListTables")
} # if (FALSE)


# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# EXPORTS
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Export all public methods, that is, those without a preceeding dot
# in their names.
exportPattern("^[^\\.]")


# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# DECLARATIONS
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
S3method("doASCRMAv1", "default")
S3method("doASCRMAv2", "default")
S3method("doCRMAv1", "default")
S3method("doCRMAv2", "default")
S3method("doFIRMA", "default")
S3method("doGCRMA", "default")
S3method("doRMA", "default")

S3method("doCRMAv1", "AffymetrixCelSet")
S3method("doCRMAv2", "AffymetrixCelSet")
S3method("doFIRMA", "AffymetrixCelSet")
S3method("doGCRMA", "AffymetrixCelSet")
S3method("doRMA", "AffymetrixCelSet")

S3method("justRMA", "AffymetrixCelSet")


S3method("addColorMap", "ArrayExplorer")
S3method("addColorMap", "SpatialReporter")
S3method("addExclCells", "DChipQuantileNormalization")
S3method("allocate", "AromaCellMatchScoreFile")
S3method("allocate", "CrlmmParametersFile")
S3method("allocateFromCdf", "AffymetrixCelFile")
S3method("allocateFromCdf", "AromaCellCpgFile")
S3method("allocateFromCdf", "AromaCellMatchScoreFile")
S3method("allocateFromCdf", "AromaCellPositionFile")
S3method("allocateFromCdf", "AromaCellSequenceFile")
S3method("allocateFromCdf", "AromaUfcFile")
S3method("allocateFromCdf", "AromaUflFile")
S3method("allocateFromCdf", "AromaUnitGcContentFile")
S3method("allocateFromCdf", "AromaUnitTabularBinaryFile")
S3method("annotateMvsA", "AffymetrixCelFile")
S3method("append", "AffymetrixCelSet")
S3method("append", "CnagCfhSet")
S3method("applyAnyOrder", "CopyNumberChromosomalModel")
S3method("applyCCF0", "CopyNumberChromosomalModel")
S3method("applyCFC0", "CopyNumberChromosomalModel")
S3method("applyToUnitIntensities", "AffymetrixCelSet")
S3method("as.AffymetrixCelSet", "AffymetrixCelSet")
S3method("as.AffymetrixCelSet", "default")
S3method("as.AffymetrixCelSet", "list")
S3method("as.AffymetrixCnChpSet", "AffymetrixCnChpSet")
S3method("as.AffymetrixCnChpSet", "default")
S3method("as.AffymetrixCnChpSet", "list")
S3method("as.AffymetrixFileSet", "AffymetrixFileSet")
S3method("as.AffymetrixFileSet", "default")
S3method("as.AffymetrixFileSet", "list")
S3method("as.ChipEffectSetTuple", "ChipEffectSetTuple")
S3method("as.ChipEffectSetTuple", "default")
S3method("as.CnChipEffectSetTuple", "CnChipEffectSetTuple")
S3method("as.CnChipEffectSetTuple", "default")
S3method("as.CnagCfhSet", "CnagCfhSet")
S3method("as.CnagCfhSet", "default")
S3method("as.CnagCfhSet", "list")
S3method("as.CopyNumberDataSetTuple", "CnChipEffectSet")
S3method("as.DChipDcpSet", "DChipDcpSet")
S3method("as.DChipDcpSet", "default")
S3method("as.DChipDcpSet", "list")
S3method("as.character", "AffymetrixCdfFile")
S3method("as.character", "AffymetrixCelFile")
S3method("as.character", "AffymetrixCelSet")
S3method("as.character", "AffymetrixCelSetReporter")
S3method("as.character", "AffymetrixCnChpFile")
S3method("as.character", "AffymetrixCnChpSet")
S3method("as.character", "AffymetrixPgfFile")
S3method("as.character", "AffymetrixProbeTabFile")
S3method("as.character", "AromaChipTypeAnnotationFile")
S3method("as.character", "ArrayExplorer")
S3method("as.character", "ChipEffectFile")
S3method("as.character", "ChipEffectSet")
S3method("as.character", "CnagCfhFile")
S3method("as.character", "CnagCfhSet")
S3method("as.character", "DChipCdfBinFile")
S3method("as.character", "DChipDcpFile")
S3method("as.character", "DChipDcpSet")
S3method("as.character", "DChipQuantileNormalization")
S3method("as.character", "FirmaModel")
S3method("as.character", "GenericReporter")
S3method("as.character", "GenomeInformation")
S3method("as.character", "Model")
S3method("as.character", "ProbeAffinityFile")
S3method("as.character", "QualityAssessmentModel")
S3method("as.character", "ResidualFile")
S3method("as.character", "ResidualSet")
S3method("as.character", "SmoothMultiarrayModel")
S3method("as.character", "SnpInformation")
S3method("as.character", "SpatialReporter")
S3method("as.character", "TransformReport")
S3method("as.character", "WeightsFile")
S3method("as.character", "WeightsSet")
S3method("assertAnnotationData", "ASCRMAv2")
S3method("averageQuantile", "AffymetrixCelSet")
S3method("boxplotStats", "ChipEffectSet")
S3method("bpmapCluster2Cdf", "default")
S3method("byChipType", "AffymetrixCsvGenomeInformation")
S3method("byChipType", "AffymetrixProbeTabFile")
S3method("byChipType", "AffymetrixTabularFile")
S3method("byChipType", "AffymetrixTsvFile")
S3method("byChipType", "AromaCellMatchScoreFile")
S3method("byChipType", "AromaChipTypeAnnotationFile")
S3method("byChipType", "DChipCdfBinFile")
S3method("byChipType", "DChipGenomeInformation")
S3method("byChipType", "DChipSnpInformation")
S3method("byChipType", "GenomeInformation")
S3method("byChipType", "SnpInformation")
S3method("byChipType", "UflSnpInformation")
S3method("byChipType", "UgpGenomeInformation")
S3method("byName", "AffymetrixCelSet")
S3method("byName", "AffymetrixCnChpSet")
S3method("byName", "AromaChipTypeAnnotationFile")
S3method("byName", "CnagCfhSet")
S3method("byName", "CrlmmParametersSet")
S3method("byName", "DChipDcpSet")
S3method("byPath", "AffymetrixCelSet")
S3method("byPath", "AffymetrixCelSetTuple")
S3method("byPath", "AffymetrixCnChpSet")
S3method("byPath", "AffymetrixFileSet")
S3method("byPath", "ChipEffectSet")
S3method("byPath", "CnChipEffectSet")
S3method("byPath", "CnagCfhSet")
S3method("byPath", "CrlmmParametersSet")
S3method("byPath", "DChipDcpSet")
S3method("byPath", "ExonChipEffectSet")
S3method("byPath", "FirmaSet")
S3method("byPath", "ResidualSet")
S3method("byPath", "SnpChipEffectSet")
S3method("byPath", "WeightsSet")
S3method("calcRawCnStats", "CopyNumberChromosomalModel")
S3method("calcRawCnStats", "default")
S3method("calculateAffinities", "GcRmaBackgroundCorrection")
S3method("calculateAverages", "FragmentEquivalentClassNormalization")
S3method("calculateBaseline", "ChipEffectSet")
S3method("calculateConfidenceScores", "CrlmmModel")
S3method("calculateFieldBoxplotStats", "ChipEffectSet")
S3method("calculateMargins", "SpatialReporter")
S3method("calculateNuseBoxplotStats", "ChipEffectSet")
S3method("calculateParametersGsb", "AffymetrixCelSet")
S3method("calculateResidualSet", "FirmaModel")
S3method("calculateResidualSet", "ProbeLevelModel")
S3method("calculateRleBoxplotStats", "ChipEffectSet")
S3method("calculateTargetDistribution", "QuantileNormalization")
S3method("calculateWeights", "ExonRmaPlm")
S3method("calculateWeights", "FirmaModel")
S3method("calculateWeights", "ProbeLevelModel")
S3method("calibrateOne", "ReseqCrosstalkCalibration")
S3method("clearCache", "AffymetrixCelSet")
S3method("clearData", "AffymetrixCelFile")
S3method("clone", "AffymetrixCelFile")
S3method("clone", "AffymetrixCelSet")
S3method("clone", "AffymetrixCnChpFile")
S3method("clone", "CnagCfhFile")
S3method("clone", "CnagCfhSet")
S3method("compare", "AffymetrixCdfFile")
S3method("computeAffinities", "AffymetrixCdfFile")
S3method("computeAffinitiesByACS", "AffymetrixCdfFile")
S3method("convert", "AffymetrixCdfFile")
S3method("convertToUnique", "AffymetrixCelSet")
S3method("convertUnits", "AffymetrixCdfFile")
S3method("createExonByTranscriptCdf", "AffymetrixCdfFile")
S3method("createFrom", "AffymetrixCelFile")
S3method("createMonocellCdf", "AffymetrixCdfFile")
S3method("createOutputTuple", "SmoothMultiarrayModel")
S3method("createParamCdf", "ChipEffectFile")
S3method("createParamCdf", "FirmaFile")
S3method("createUniqueCdf", "AffymetrixCdfFile")
S3method("decode", "ParameterCelFile")
S3method("dim", "DChipDcpFile")
S3method("encode", "ParameterCelFile")
S3method("excludeChrXFromFit", "DChipQuantileNormalization")
S3method("exportAromaSignalBinaryFileList", "CnChipEffectFile")
S3method("exportTotalAndFracB", "CnChipEffectFile")
S3method("exportTotalAndFracB", "CnChipEffectSet")
S3method("exportTotalAndFracB", "DChipDcpSet")
S3method("exportTotalAndFracB", "SnpChipEffectFile")
S3method("exportTotalAndFracB", "SnpChipEffectSet")
S3method("exportTotalCnRatioSet", "AffymetrixCnChpSet")
S3method("extractAffyBatch", "AffymetrixCelSet")
S3method("extractAffyBatch", "ChipEffectSet")
S3method("extractAlleleSet", "SnpChipEffectSet")
S3method("extractCNT", "SnpChipEffectFile")
S3method("extractCNT", "SnpChipEffectSet")
S3method("extractChromosomalDataFrame", "ChipEffectFile")
S3method("extractChromosomalDataFrame", "ChipEffectSet")
S3method("extractDataFrame", "ParameterCelFile")
S3method("extractDataFrame", "ParameterCelSet")
S3method("extractExpressionSet", "ChipEffectSet")
S3method("extractFeatureSet", "AffymetrixCelSet")
S3method("extractLogRatios", "AffymetrixCnChpFile")
S3method("extractLogRatios", "AffymetrixCnChpSet")
S3method("extractMatrix", "AffymetrixCelFile")
S3method("extractMatrix", "AffymetrixCelSet")
S3method("extractMatrix", "ChipEffectFile")
S3method("extractMatrix", "ChipEffectSet")
S3method("extractMatrix", "FirmaFile")
S3method("extractMatrix", "FirmaSet")
S3method("extractMatrix", "ParameterCelFile")
S3method("extractMatrix", "ParameterCelSet")
S3method("extractSnpCnvQSet", "SnpChipEffectSet")
S3method("extractSnpFeatureSet", "AffymetrixCelSet")
S3method("extractSnpQSet", "SnpChipEffectSet")
S3method("extractTheta", "ChipEffectFile")
S3method("extractTheta", "ChipEffectSet")
S3method("extractTheta", "CnChipEffectFile")
S3method("extractTheta", "CnChipEffectSet")
S3method("extractTheta", "DChipDcpFile")
S3method("extractTheta", "DChipDcpSet")
S3method("extractTheta", "SnpChipEffectFile")
S3method("extractTheta", "SnpChipEffectSet")
S3method("extractTheta", "SnpCnvQSet")
S3method("extractTheta", "SnpQSet")
S3method("extractTotalAndFracB", "SnpChipEffectFile")
S3method("extractTotalAndFreqB", "CnChipEffectFile")
S3method("extractTotalAndFreqB", "CnChipEffectSet")
S3method("extractTotalAndFreqB", "SnpChipEffectSet")
S3method("extractTotalAndFreqB", "default")
S3method("findByCdf2", "default")
S3method("findByChipType", "AffymetrixCdfFile")
S3method("findByChipType", "AffymetrixCsvFile")
S3method("findByChipType", "AffymetrixCsvGenomeInformation")
S3method("findByChipType", "AffymetrixNetAffxCsvFile")
S3method("findByChipType", "AffymetrixPgfFile")
S3method("findByChipType", "AffymetrixProbeTabFile")
S3method("findByChipType", "AffymetrixTabularFile")
S3method("findByChipType", "AffymetrixTsvFile")
S3method("findByChipType", "AromaChipTypeAnnotationFile")
S3method("findByChipType", "DChipCdfBinFile")
S3method("findByChipType", "DChipGenomeInformation")
S3method("findByChipType", "DChipSnpInformation")
S3method("findByChipType", "UflSnpInformation")
S3method("findByChipType", "UgpGenomeInformation")
S3method("findByName", "AffymetrixCelSet")
S3method("findByName", "AffymetrixCnChpSet")
S3method("findByName", "ChipEffectSet")
S3method("findByName", "CnagCfhSet")
S3method("findByName", "DChipDcpSet")
S3method("findTargetDistributionFile", "QuantileNormalization")
S3method("findUnitsTodo", "AlleleSummation")
S3method("findUnitsTodo", "ChipEffectFile")
S3method("findUnitsTodo", "ChipEffectSet")
S3method("findUnitsTodo", "CrlmmModel")
S3method("findUnitsTodo", "CrlmmParametersFile")
S3method("findUnitsTodo", "CrlmmParametersSet")
S3method("findUnitsTodo", "ExonChipEffectSet")
S3method("findUnitsTodo", "FirmaFile")
S3method("findUnitsTodo", "FirmaModel")
S3method("findUnitsTodo", "FirmaSet")
S3method("findUnitsTodo", "ProbeLevelModel")
S3method("findUnitsTodo", "QualityAssessmentFile")
S3method("findUnitsTodo", "ResidualFile")
S3method("findUnitsTodo", "ResidualSet")
S3method("findUnitsTodo", "UnitModel")
S3method("findUnitsTodo", "WeightsFile")
S3method("findUnitsTodo", "WeightsSet")
S3method("fit", "CrlmmModel")
S3method("fit", "FirmaModel")
S3method("fit", "Model")
S3method("fit", "ProbeLevelModel")
S3method("fit", "SingleArrayUnitModel")
S3method("fit", "SmoothMultiarrayModel")
S3method("fitCnProbes", "UnitModel")
S3method("fitOne", "AbstractProbeSequenceNormalization")
S3method("fitOne", "BaseCountNormalization")
S3method("fitOne", "LinearModelProbeSequenceNormalization")
S3method("fitOne", "MatNormalization")
S3method("fitOne", "ReseqCrosstalkCalibration")
S3method("fitOne", "ScaleNormalization3")
S3method("fitOne", "UnitTypeScaleNormalization")
S3method("fitOneArray", "SingleArrayUnitModel")
S3method("fitOneChromosome", "SmoothMultiarrayModel")
S3method("fitPlasqUnit", "matrix")
S3method("fitQuantileNormFcn", "AffymetrixCelFile")
S3method("fixSearchPath", "AromaAffymetrix")
S3method("fromCdf", "AffymetrixProbeTabFile")
S3method("fromCdf", "GenomeInformation")
S3method("fromCdf", "SnpInformation")
S3method("fromDataFile", "ChipEffectFile")
S3method("fromDataFile", "FirmaFile")
S3method("fromDataFile", "ResidualFile")
S3method("fromDataFile", "WeightsFile")
S3method("fromDataSet", "ChipEffectSet")
S3method("fromDataSet", "FirmaSet")
S3method("fromDataSet", "GenomeInformation")
S3method("fromDataSet", "ResidualSet")
S3method("fromDataSet", "SnpInformation")
S3method("fromDataSet", "WeightsSet")
S3method("fromFile", "AffymetrixCdfFile")
S3method("fromFile", "AffymetrixCelFile")
S3method("fromFile", "AffymetrixCnChpFile")
S3method("fromFile", "AffymetrixPgfFile")
S3method("fromFile", "AromaChipTypeAnnotationFile")
S3method("fromFile", "CnagCfhFile")
S3method("fromFile", "DChipCdfBinFile")
S3method("fromFile", "DChipDcpFile")
S3method("getACSFile", "AffymetrixCdfFile")
S3method("getAM", "ChipEffectFile")
S3method("getAM", "ChipEffectSet")
S3method("getAlias", "ArrayExplorer")
S3method("getAlias", "GenericReporter")
S3method("getAlias", "Model")
S3method("getAlias", "TransformReport")
S3method("getAlleleCellPairs", "AffymetrixCdfFile")
S3method("getAlleleProbePairs", "AffymetrixCdfFile")
S3method("getAlleleProbePairs2", "AffymetrixCdfFile")
S3method("getAlleleProbePairs3", "AffymetrixCdfFile")
S3method("getAm", "AffymetrixCelFile")
S3method("getAromaCellMatchScoreFile", "MatNormalization")
S3method("getAromaCellPositionFile", "MatSmoothing")
S3method("getAromaCellSequenceFile", "AbstractProbeSequenceNormalization")
S3method("getAromaCellSequenceFile", "AffymetrixCdfFile")
S3method("getAromaUfcFile", "FragmentEquivalentClassNormalization")
S3method("getAromaUflFile", "UflSnpInformation")
S3method("getAromaUgpFile", "UgpGenomeInformation")
S3method("getAromaUnitFracBCnBinarySet", "default")
S3method("getAromaUnitTotalCnBinarySet", "default")
S3method("getArrayNames", "AffymetrixAptSummaryFile")
S3method("getArraysOfInput", "ArrayExplorer")
S3method("getAsFullCelFile", "ChipEffectFile")
S3method("getAsFullCelSet", "ChipEffectSet")
S3method("getAsteriskTags", "AdditiveCovariatesNormalization")
S3method("getAsteriskTags", "AffineCnPlm")
S3method("getAsteriskTags", "AffinePlm")
S3method("getAsteriskTags", "AffineSnpPlm")
S3method("getAsteriskTags", "AlleleSummation")
S3method("getAsteriskTags", "AllelicCrosstalkCalibration")
S3method("getAsteriskTags", "ArrayExplorer")
S3method("getAsteriskTags", "AvgCnPlm")
S3method("getAsteriskTags", "AvgPlm")
S3method("getAsteriskTags", "AvgSnpPlm")
S3method("getAsteriskTags", "BaseCountNormalization")
S3method("getAsteriskTags", "BasePositionNormalization")
S3method("getAsteriskTags", "CrlmmModel")
S3method("getAsteriskTags", "ExonRmaPlm")
S3method("getAsteriskTags", "FirmaModel")
S3method("getAsteriskTags", "FragmentEquivalentClassNormalization")
S3method("getAsteriskTags", "FragmentLengthNormalization")
S3method("getAsteriskTags", "GenericReporter")
S3method("getAsteriskTags", "HetLogAddCnPlm")
S3method("getAsteriskTags", "HetLogAddPlm")
S3method("getAsteriskTags", "HetLogAddSnpPlm")
S3method("getAsteriskTags", "LimmaBackgroundCorrection")
S3method("getAsteriskTags", "MatNormalization")
S3method("getAsteriskTags", "MbeiCnPlm")
S3method("getAsteriskTags", "MbeiPlm")
S3method("getAsteriskTags", "MbeiSnpPlm")
S3method("getAsteriskTags", "Model")
S3method("getAsteriskTags", "NormExpBackgroundCorrection")
S3method("getAsteriskTags", "ProbeLevelModel")
S3method("getAsteriskTags", "ProbeLevelTransform3")
S3method("getAsteriskTags", "QualityAssessmentModel")
S3method("getAsteriskTags", "ReseqCrosstalkCalibration")
S3method("getAsteriskTags", "RmaCnPlm")
S3method("getAsteriskTags", "RmaPlm")
S3method("getAsteriskTags", "RmaSnpPlm")
S3method("getAsteriskTags", "ScaleNormalization")
S3method("getAsteriskTags", "SmoothMultiarrayModel")
S3method("getAsteriskTags", "SmoothRmaModel")
S3method("getAsteriskTags", "SmoothSaModel")
S3method("getAsteriskTags", "SnpChipEffectGroupMerge")
S3method("getAsteriskTags", "UnitModel")
S3method("getAverage", "AffymetrixCelSet")
S3method("getAverage", "CnagCfhSet")
S3method("getAverageAsinh", "AffymetrixCelSet")
S3method("getAverageAsinh", "CnagCfhSet")
S3method("getAverageFile", "AffymetrixCelSet")
S3method("getAverageFile", "ChipEffectSet")
S3method("getAverageFile", "CnChipEffectSet")
S3method("getAverageFile", "CnagCfhSet")
S3method("getAverageFile", "ExonChipEffectSet")
S3method("getAverageFile", "ResidualSet")
S3method("getAverageFile", "SnpChipEffectSet")
S3method("getAverageFile", "WeightsSet")
S3method("getAverageLog", "AffymetrixCelSet")
S3method("getAverageLog", "CnagCfhSet")
S3method("getBandwidth", "SmoothMultiarrayModel")
S3method("getBaseline", "ChipEffectSet")
S3method("getBaseline", "CnChipEffectSet")
S3method("getBaseline", "SnpChipEffectSet")
S3method("getBlockSizes", "SpatialRowColumnNormalization")
S3method("getCalculateResidualsFunction", "AvgPlm")
S3method("getCalculateResidualsFunction", "ProbeLevelModel")
S3method("getCalculateResidualsFunction", "RmaPlm")
S3method("getCallSet", "CrlmmModel")
S3method("getCalls", "DChipDcpFile")
S3method("getCdf", "AdditiveCovariatesNormalization")
S3method("getCdf", "AffymetrixCelFile")
S3method("getCdf", "AffymetrixCelSet")
S3method("getCdf", "AffymetrixCnChpFile")
S3method("getCdf", "AffymetrixCnChpSet")
S3method("getCdf", "AffymetrixProbeTabFile")
S3method("getCdf", "AffymetrixTsvFile")
S3method("getCdf", "AromaUnitTabularBinaryFile")
S3method("getCdf", "ChipEffectGroupMerge")
S3method("getCdf", "CnagCfhFile")
S3method("getCdf", "CnagCfhSet")
S3method("getCdf", "FirmaModel")
S3method("getCdf", "FragmentEquivalentClassNormalization")
S3method("getCdf", "FragmentLengthNormalization")
S3method("getCdf", "GcContentNormalization")
S3method("getCdf", "Model")
S3method("getCdf", "QualityAssessmentModel")
S3method("getCdf", "TransformReport")
S3method("getCdfBin", "DChipDcpSet")
S3method("getCellDim", "DChipCdfBinFile")
S3method("getCellIndices", "AffymetrixCdfFile")
S3method("getCellIndices", "ChipEffectFile")
S3method("getCellIndices", "ChipEffectSet")
S3method("getCellIndices", "CnChipEffectFile")
S3method("getCellIndices", "CnPlm")
S3method("getCellIndices", "CnProbeAffinityFile")
S3method("getCellIndices", "ExonChipEffectFile")
S3method("getCellIndices", "ExonProbeAffinityFile")
S3method("getCellIndices", "ExonRmaPlm")
S3method("getCellIndices", "FirmaFile")
S3method("getCellIndices", "FirmaSet")
S3method("getCellIndices", "ProbeAffinityFile")
S3method("getCellIndices", "ResidualFile")
S3method("getCellIndices", "ResidualSet")
S3method("getCellIndices", "SnpChipEffectFile")
S3method("getCellIndices", "SnpPlm")
S3method("getCellIndices", "SnpProbeAffinityFile")
S3method("getCellIndices", "UnitModel")
S3method("getCellIndices", "WeightsFile")
S3method("getCellIndices", "WeightsSet")
S3method("getCellMapForMainCdf", "ChipEffectFile")
S3method("getCellQuartets", "AffymetrixCdfFile")
S3method("getCellsTo", "ProbeLevelTransform3")
S3method("getCellsToFit", "ProbeLevelTransform3")
S3method("getCellsToInternal", "ProbeLevelTransform3")
S3method("getCellsToUpdate", "ProbeLevelTransform3")
S3method("getChipEffectFileClass", "ChipEffectSet")
S3method("getChipEffectFileClass", "CnChipEffectSet")
S3method("getChipEffectFileClass", "ExonChipEffectSet")
S3method("getChipEffectFileClass", "SnpChipEffectSet")
S3method("getChipEffectSet", "AlleleSummation")
S3method("getChipEffectSet", "CnPlm")
S3method("getChipEffectSet", "ExonRmaPlm")
S3method("getChipEffectSet", "ProbeLevelModel")
S3method("getChipEffectSet", "QualityAssessmentModel")
S3method("getChipEffectSet", "SnpPlm")
S3method("getChipEffectSetClass", "AlleleSummation")
S3method("getChipEffectSetClass", "CnPlm")
S3method("getChipEffectSetClass", "ExonRmaPlm")
S3method("getChipEffectSetClass", "ProbeLevelModel")
S3method("getChipEffectSetClass", "SnpPlm")
S3method("getChipType", "AffymetrixAptSummaryFile")
S3method("getChipType", "AffymetrixCdfFile")
S3method("getChipType", "AffymetrixCelFile")
S3method("getChipType", "AffymetrixCelSet")
S3method("getChipType", "AffymetrixCelSetReporter")
S3method("getChipType", "AffymetrixCnChpFile")
S3method("getChipType", "AffymetrixPgfFile")
S3method("getChipType", "AffymetrixProbeTabFile")
S3method("getChipType", "AffymetrixTsvFile")
S3method("getChipType", "AromaChipTypeAnnotationFile")
S3method("getChipType", "CnagCfhFile")
S3method("getChipType", "CrlmmModel")
S3method("getChipType", "DChipCdfBinFile")
S3method("getChipType", "DChipDcpSet")
S3method("getChipType", "GenomeInformation")
S3method("getChipType", "SnpInformation")
S3method("getChipType", "UflSnpInformation")
S3method("getChipType", "UgpGenomeInformation")
S3method("getChromosomeStats", "GenomeInformation")
S3method("getChromosomes", "GenomeInformation")
S3method("getChromosomes", "UgpGenomeInformation")
S3method("getCnNames", "AffymetrixCdfFile")
S3method("getColorMaps", "ArrayExplorer")
S3method("getColorMaps", "SpatialReporter")
S3method("getColumnNames", "AffymetrixProbeTabFile")
S3method("getCombineAlleles", "CnChipEffectSet")
S3method("getCombineAlleles", "CnPlm")
S3method("getConfidenceScoreSet", "CrlmmModel")
S3method("getCovariates", "AdditiveCovariatesNormalization")
S3method("getCovariates", "GcContentNormalization2")
S3method("getCrlmmParametersSet", "CrlmmModel")
S3method("getCrlmmPriors", "CrlmmModel")
S3method("getCrlmmSNPs", "CrlmmModel")
S3method("getCrlmmSNPsOnChrX", "CrlmmModel")
S3method("getCrlmmSplineParameters", "CrlmmModel")
S3method("getData", "AffymetrixCelFile")
S3method("getData", "AffymetrixCelSet")
S3method("getData", "AffymetrixCnChpFile")
S3method("getData", "AffymetrixProbeTabFile")
S3method("getData", "AffymetrixTsvFile")
S3method("getData", "CnagCfhSet")
S3method("getData", "GenomeInformation")
S3method("getData", "SnpInformation")
S3method("getData", "UflSnpInformation")
S3method("getData", "UgpGenomeInformation")
S3method("getDataColumns", "GenomeInformation")
S3method("getDataColumns", "UflSnpInformation")
S3method("getDataColumns", "UgpGenomeInformation")
S3method("getDataFlat", "ChipEffectFile")
S3method("getDataFlat", "FirmaFile")
S3method("getDataFlat", "ResidualFile")
S3method("getDataFlat", "WeightsFile")
S3method("getDataPairs", "AllelicCrosstalkCalibration")
S3method("getDataSet", "AffymetrixCelSetReporter")
S3method("getDataSet", "ArrayExplorer")
S3method("getDataSet", "FirmaModel")
S3method("getDataSet", "Model")
S3method("getDataSet", "QualityAssessmentModel")
S3method("getDefaultColumnNames", "AromaCellMatchScoreFile")
S3method("getDefaultColumnNames", "AromaUfcFile")
S3method("getDefaultExtension", "AffymetrixCdfFile")
S3method("getDefaultExtension", "AffymetrixCsvFile")
S3method("getDefaultExtension", "AffymetrixCsvGenomeInformation")
S3method("getDefaultExtension", "AffymetrixNetAffxCsvFile")
S3method("getDefaultExtension", "AffymetrixPgfFile")
S3method("getDefaultExtension", "AffymetrixTsvFile")
S3method("getDefaultExtension", "AromaCellMatchScoreFile")
S3method("getDefaultExtension", "AromaChipTypeAnnotationFile")
S3method("getDefaultFullName", "AffymetrixFileSet")
S3method("getDefaultFullName", "CnagCfhSet")
S3method("getDefaultSettings", "AromaAffymetrix")
S3method("getDefaultSettings", "Package")
S3method("getDesignMatrix", "BaseCountNormalization")
S3method("getDesignMatrix", "BasePositionNormalization")
S3method("getDesignMatrix", "LinearModelProbeSequenceNormalization")
S3method("getDesignMatrix", "MatNormalization")
S3method("getDimension", "AffymetrixCdfFile")
S3method("getDimension", "AffymetrixPgfFile")
S3method("getExclCells", "DChipQuantileNormalization")
S3method("getExclCells", "QuantileNormalization")
S3method("getExcludes", "DChipDcpFile")
S3method("getExclusiveUnitSubsets", "FragmentEquivalentClassNormalization")
S3method("getExpandedCellMap", "ChipEffectFile")
S3method("getExpandedCellMap", "CnChipEffectFile")
S3method("getExpandedCellMap", "SnpChipEffectFile")
S3method("getExpectedOutputFullnames", "MatSmoothing")
S3method("getExtensionPattern", "AffymetrixCdfFile")
S3method("getExtensionPattern", "AffymetrixCelFile")
S3method("getExtensionPattern", "AffymetrixCnChpFile")
S3method("getExtensionPattern", "AffymetrixCsvFile")
S3method("getExtensionPattern", "AffymetrixPgfFile")
S3method("getExtensionPattern", "AffymetrixTsvFile")
S3method("getExtensionPattern", "AromaCellMatchScoreFile")
S3method("getExtensionPattern", "AromaUfcFile")
S3method("getExtensionPattern", "CnagCfhFile")
S3method("getExtensionPattern", "DChipDcpFile")
S3method("getField", "AffymetrixTsvFile")
S3method("getFields", "SnpInformation")
S3method("getFields", "UflSnpInformation")
S3method("getFileClass", "FirmaSet")
S3method("getFileFormat", "AffymetrixCdfFile")
S3method("getFileFormat", "AffymetrixCelFile")
S3method("getFileFormat", "AffymetrixCnChpFile")
S3method("getFileFormat", "DChipCdfBinFile")
S3method("getFileFormat", "DChipDcpFile")
S3method("getFileSet", "AffymetrixFileSetReporter")
S3method("getFileSetClass", "FirmaModel")
S3method("getFilenameExtension", "AromaCellMatchScoreFile")
S3method("getFilenameExtension", "AromaUfcFile")
S3method("getFilteredFragmentLengths", "FragmentLengthNormalization")
S3method("getFirmaScores", "FirmaModel")
S3method("getFirmaSet", "FirmaModel")
S3method("getFirstCellIndices", "AffymetrixCdfFile")
S3method("getFirstCellPerUnitIndices", "ExonChipEffectSet")
S3method("getFit", "BasePositionNormalization")
S3method("getFitSingleCellUnitFunction", "UnitModel")
S3method("getFitUnitFunction", "CnPlm")
S3method("getFitUnitFunction", "FirmaModel")
S3method("getFitUnitFunction", "MultiArrayUnitModel")
S3method("getFitUnitFunction", "SingleArrayUnitModel")
S3method("getFitUnitFunction", "UnitModel")
S3method("getFitUnitGroupFunction", "AffinePlm")
S3method("getFitUnitGroupFunction", "AvgPlm")
S3method("getFitUnitGroupFunction", "ExonRmaPlm")
S3method("getFitUnitGroupFunction", "FirmaModel")
S3method("getFitUnitGroupFunction", "HetLogAddPlm")
S3method("getFitUnitGroupFunction", "MbeiPlm")
S3method("getFitUnitGroupFunction", "MultiArrayUnitModel")
S3method("getFitUnitGroupFunction", "RmaPlm")
S3method("getFitUnitGroupFunction", "SingleArrayUnitModel")
S3method("getFitUnitGroupFunction", "SmoothMultiarrayModel")
S3method("getFitUnitGroupFunction", "SmoothRmaModel")
S3method("getFitUnitGroupFunction", "SmoothSaModel")
S3method("getFragmentLengths", "AffymetrixTsvFile")
S3method("getFragmentLengths", "SnpInformation")
S3method("getFragmentLengths", "UflSnpInformation")
S3method("getFragmentStarts", "SnpInformation")
S3method("getFragmentStarts", "UflSnpInformation")
S3method("getFragmentStops", "SnpInformation")
S3method("getFragmentStops", "UflSnpInformation")
S3method("getFullName", "GenericReporter")
S3method("getFullName", "Model")
S3method("getFullName", "QualityAssessmentModel")
S3method("getFullName", "TransformReport")
S3method("getFullNames", "ChipEffectSetTuple")
S3method("getGc", "AffymetrixTsvFile")
S3method("getGcContent", "GcContentNormalization")
S3method("getGenomeBuild", "AffymetrixNetAffxCsvFile")
S3method("getGenomeInformation", "AffymetrixCdfFile")
S3method("getGroupDirections", "AffymetrixCdfFile")
S3method("getHeader", "AffymetrixCdfFile")
S3method("getHeader", "AffymetrixCelFile")
S3method("getHeader", "AffymetrixCnChpFile")
S3method("getHeader", "AffymetrixPgfFile")
S3method("getHeader", "AromaChipTypeAnnotationFile")
S3method("getHeader", "CnagCfhFile")
S3method("getHeader", "DChipCdfBinFile")
S3method("getHeader", "DChipDcpFile")
S3method("getHeaderAttributes", "AffymetrixNetAffxCsvFile")
S3method("getHeaderLength", "CnagCfhFile")
S3method("getHeaderV3", "AffymetrixCelFile")
S3method("getIdentifier", "AffymetrixCelFile")
S3method("getIdentifier", "AffymetrixCelSet")
S3method("getIdentifier", "AffymetrixFileSet")
S3method("getIdentifier", "CnagCfhFile")
S3method("getIdentifier", "CnagCfhSet")
S3method("getImage", "AffymetrixCdfFile")
S3method("getImage", "AffymetrixCelFile")
S3method("getImage", "AromaUnitTabularBinaryFile")
S3method("getImage", "ResidualFile")
S3method("getImage", "WeightsFile")
S3method("getIndexToRowMap", "AffymetrixProbeTabFile")
S3method("getInputDataSet", "TransformReport")
S3method("getInputName", "AffymetrixFileSetReporter")
S3method("getInputName", "GenericReporter")
S3method("getInputTags", "AffymetrixFileSetReporter")
S3method("getInputTags", "GenericReporter")
S3method("getIntensities", "AffymetrixCelSet")
S3method("getLabel", "Model")
S3method("getListOfCdfs", "AffymetrixCelSetTuple")
S3method("getListOfGenomeInformations", "ChromosomalModel")
S3method("getListOfPriors", "MultiArrayUnitModel")
S3method("getListOfReporters", "ArrayExplorer")
S3method("getListOfUnitNamesFiles", "AffymetrixCelSetTuple")
S3method("getListOfUnitNamesFiles", "ArrayExplorer")
S3method("getListOfUnitTypesFiles", "AffymetrixCelSetTuple")
S3method("getListOfUnitTypesFiles", "ArrayExplorer")
S3method("getMainCdf", "AffymetrixCdfFile")
S3method("getMainPath", "GenericReporter")
S3method("getMergeFunction", "ChipEffectGroupMerge")
S3method("getMergeFunction", "SnpChipEffectGroupMerge")
S3method("getMergeGroups", "ExonChipEffectSet")
S3method("getMergeStrands", "SnpChipEffectSet")
S3method("getMergeStrands", "SnpPlm")
S3method("getMonocellCdf", "AffymetrixCdfFile")
S3method("getName", "AffymetrixPlatform")
S3method("getName", "FirmaModel")
S3method("getName", "GenericReporter")
S3method("getName", "Model")
S3method("getName", "QualityAssessmentModel")
S3method("getName", "TransformReport")
S3method("getNameOfInput", "ArrayExplorer")
S3method("getNetAffxBuild", "AffymetrixNetAffxCsvFile")
S3method("getNetAffxDate", "AffymetrixNetAffxCsvFile")
S3method("getNormalEquations", "LinearModelProbeSequenceNormalization")
S3method("getNormalizeSignalsOne", "ScaleNormalization3")
S3method("getNormalizeSignalsOne", "UnitTypeScaleNormalization")
S3method("getNormalizedIntensities", "DChipDcpFile")
S3method("getNumberOfFilesAveraged", "CnChipEffectFile")
S3method("getOrderedFragmentPairMap", "AromaUfcFile")
S3method("getOrderedFragmentPairs", "AromaUfcFile")
S3method("getOutputDataSet", "Transform")
S3method("getOutputDataSet", "TransformReport")
S3method("getOutputDataSet00", "AdditiveCovariatesNormalization")
S3method("getOutputDataSet00", "FragmentEquivalentClassNormalization")
S3method("getOutputDataSet00", "FragmentLengthNormalization")
S3method("getOutputDataSet00", "GcContentNormalization")
S3method("getOutputFiles", "Transform")
S3method("getOutputIdentifier", "QuantileNormalization")
S3method("getOutputTuple", "SmoothMultiarrayModel")
S3method("getParameter", "AffymetrixAptSummaryFile")
S3method("getParameters", "AbstractProbeSequenceNormalization")
S3method("getParameters", "AdditiveCovariatesNormalization")
S3method("getParameters", "AllelicCrosstalkCalibration")
S3method("getParameters", "AvgPlm")
S3method("getParameters", "BackgroundCorrection")
S3method("getParameters", "BaseCountNormalization")
S3method("getParameters", "BasePositionNormalization")
S3method("getParameters", "ChipEffectFile")
S3method("getParameters", "ChipEffectGroupMerge")
S3method("getParameters", "CnChipEffectFile")
S3method("getParameters", "CnPlm")
S3method("getParameters", "CrlmmModel")
S3method("getParameters", "DChipQuantileNormalization")
S3method("getParameters", "ExonChipEffectFile")
S3method("getParameters", "ExonRmaPlm")
S3method("getParameters", "FragmentEquivalentClassNormalization")
S3method("getParameters", "FragmentLengthNormalization")
S3method("getParameters", "GcContentNormalization")
S3method("getParameters", "GcRmaBackgroundCorrection")
S3method("getParameters", "LimmaBackgroundCorrection")
S3method("getParameters", "MatNormalization")
S3method("getParameters", "MatSmoothing")
S3method("getParameters", "NormExpBackgroundCorrection")
S3method("getParameters", "OpticalBackgroundCorrection")
S3method("getParameters", "ProbeAffinityFile")
S3method("getParameters", "ProbeLevelTransform3")
S3method("getParameters", "QuantileNormalization")
S3method("getParameters", "ReseqCrosstalkCalibration")
S3method("getParameters", "ResidualFile")
S3method("getParameters", "ResidualSet")
S3method("getParameters", "RmaBackgroundCorrection")
S3method("getParameters", "RmaPlm")
S3method("getParameters", "ScaleNormalization")
S3method("getParameters", "ScaleNormalization3")
S3method("getParameters", "SnpChipEffectFile")
S3method("getParameters", "SnpChipEffectGroupMerge")
S3method("getParameters", "SnpPlm")
S3method("getParameters", "SpatialRowColumnNormalization")
S3method("getParameters", "UnitModel")
S3method("getParameters", "UnitTypeScaleNormalization")
S3method("getParameters", "WeightsFile")
S3method("getParameters", "WeightsSet")
S3method("getPath", "AffymetrixCelSetReporter")
S3method("getPath", "GenericReporter")
S3method("getPath", "Model")
S3method("getPath", "QualityAssessmentModel")
S3method("getPath", "TransformReport")
S3method("getPcuTheta", "ChromosomalModel")
S3method("getPlatform", "AffymetrixCdfFile")
S3method("getPlatform", "AffymetrixCelFile")
S3method("getPlatform", "AffymetrixCelSet")
S3method("getPlatform", "AffymetrixPgfFile")
S3method("getPlatform", "AromaChipTypeAnnotationFile")
S3method("getPlatform", "DChipCdfBinFile")
S3method("getPlatformDesignDB", "CrlmmModel")
S3method("getPlm", "FirmaModel")
S3method("getPlm", "QualityAssessmentModel")
S3method("getPosition", "AffymetrixTsvFile")
S3method("getPositionChipTypeUnit", "ChromosomalModel")
S3method("getPositionChipTypeUnit", "CopyNumberSegmentationModel")
S3method("getPositions", "GenomeInformation")
S3method("getProbeAffinityFile", "AffinePlm")
S3method("getProbeAffinityFile", "AvgPlm")
S3method("getProbeAffinityFile", "CnPlm")
S3method("getProbeAffinityFile", "ExonRmaPlm")
S3method("getProbeAffinityFile", "MbeiPlm")
S3method("getProbeAffinityFile", "ProbeLevelModel")
S3method("getProbeAffinityFile", "RmaPlm")
S3method("getProbeAffinityFile", "SnpPlm")
S3method("getProbeSequenceData", "AffymetrixCdfFile")
S3method("getProbesetIds", "AffymetrixAptSummaryFile")
S3method("getQuantificationScale", "AffymetrixAptSummaryFile")
S3method("getRawIntensities", "DChipDcpFile")
S3method("getReadArguments", "AffymetrixAptSummaryFile")
S3method("getRectangle", "AffymetrixCelFile")
S3method("getReference", "SpatialReporter")
S3method("getRegions", "profileCGH")
S3method("getReportSet", "GenericReporter")
S3method("getReportSet", "SpatialReporter")
S3method("getResidualFileClass", "ResidualSet")
S3method("getResidualSet", "ProbeLevelModel")
S3method("getResidualSetClass", "ProbeLevelModel")
S3method("getResiduals", "QualityAssessmentModel")
S3method("getRestructor", "AffymetrixCdfFile")
S3method("getRlmFitFunctions", "RmaPlm")
S3method("getRootPath", "AlleleSummation")
S3method("getRootPath", "ChipEffectTransform")
S3method("getRootPath", "CrlmmModel")
S3method("getRootPath", "FirmaModel")
S3method("getRootPath", "GenericReporter")
S3method("getRootPath", "Model")
S3method("getRootPath", "ProbeLevelModel")
S3method("getRootPath", "ProbeLevelTransform")
S3method("getRootPath", "QualityAssessmentModel")
S3method("getRootPath", "SmoothMultiarrayModel")
S3method("getRootPath", "SmoothRmaModel")
S3method("getRootPath", "TransformReport")
S3method("getSetTuple", "ArrayExplorer")
S3method("getSetsOfProbes", "AllelicCrosstalkCalibration")
S3method("getSetsOfProbes", "ReseqCrosstalkCalibration")
S3method("getSettings", "Package")
S3method("getSignalTransform", "BasePositionNormalization")
S3method("getSignalTransform", "LinearModelProbeSequenceNormalization")
S3method("getSnpInformation", "AffymetrixCdfFile")
S3method("getSnpNames", "AffymetrixCdfFile")
S3method("getSpar", "SpatialRowColumnNormalization")
S3method("getSteps", "ASCRMAv2")
S3method("getSteps", "AromaPipeline")
S3method("getSubsetOfCellIndices", "AffymetrixCdfFile")
S3method("getSubsetOfUnits", "AffymetrixCdfFile")
S3method("getSubsetToAvg", "AllelicCrosstalkCalibration")
S3method("getSubsetToAvg", "QuantileNormalization")
S3method("getSubsetToAvg", "ReseqCrosstalkCalibration")
S3method("getSubsetToAvg", "ScaleNormalization")
S3method("getSubsetToFit", "AdditiveCovariatesNormalization")
S3method("getSubsetToFit", "FragmentEquivalentClassNormalization")
S3method("getSubsetToFit", "FragmentLengthNormalization")
S3method("getSubsetToFit", "GcContentNormalization")
S3method("getSubsetToUpdate", "BackgroundCorrection")
S3method("getSubsetToUpdate", "DChipQuantileNormalization")
S3method("getSubsetToUpdate", "QuantileNormalization")
S3method("getSubsetToUpdate", "ScaleNormalization")
S3method("getSubsetToUpdate0", "LimmaBackgroundCorrection")
S3method("getTags", "FirmaModel")
S3method("getTags", "GenericReporter")
S3method("getTags", "Model")
S3method("getTags", "QualityAssessmentModel")
S3method("getTags", "TransformReport")
S3method("getTagsOfInput", "ArrayExplorer")
S3method("getTargetAverages", "FragmentEquivalentClassNormalization")
S3method("getTargetDistribution", "QuantileNormalization")
S3method("getTargetDistributionIdentifier", "QuantileNormalization")
S3method("getTargetDistributionPathname", "QuantileNormalization")
S3method("getTargetFile", "AbstractProbeSequenceNormalization")
S3method("getTargetFunction", "GcContentNormalization")
S3method("getTargetFunctions", "AdditiveCovariatesNormalization")
S3method("getTargetFunctions", "FragmentLengthNormalization")
S3method("getThetaStds", "DChipDcpFile")
S3method("getThetas", "DChipDcpFile")
S3method("getThetasAB", "DChipDcpFile")
S3method("getTimeStamp", "AffymetrixAptSummaryFile")
S3method("getTimestamp", "AffymetrixCelFile")
S3method("getTimestamp", "AffymetrixCnChpFile")
S3method("getTimestamp", "CnagCfhFile")
S3method("getTimestamps", "AffymetrixCelSet")
S3method("getTimestamps", "CnagCfhSet")
S3method("getUniqueCdf", "AffymetrixCdfFile")
S3method("getUnitGroupCellArrayMap", "ChipEffectFile")
S3method("getUnitGroupCellChromosomePositionMap", "AffymetrixCdfFile")
S3method("getUnitGroupCellChromosomePositionMap", "ChipEffectFile")
S3method("getUnitGroupCellMap", "AffymetrixCdfFile")
S3method("getUnitGroupCellMap", "AffymetrixCelSet")
S3method("getUnitGroupCellMap", "ChipEffectFile")
S3method("getUnitGroupCellMap", "FirmaFile")
S3method("getUnitGroupCellMap", "ResidualFile")
S3method("getUnitGroupCellMap", "WeightsFile")
S3method("getUnitGroupCellMapWithMonocell", "AffymetrixCdfFile")
S3method("getUnitGroupCellMapWithUnique", "AffymetrixCdfFile")
S3method("getUnitGroupCellMatrixMap", "ChipEffectFile")
S3method("getUnitGroupNamesFromUgcMap", "AffymetrixCdfFile")
S3method("getUnitIndices", "GenomeInformation")
S3method("getUnitIntensities", "AffymetrixCelSet")
S3method("getUnitNames", "AffymetrixCdfFile")
S3method("getUnitNames", "AffymetrixNetAffxCsvFile")
S3method("getUnitNames", "AffymetrixPgfFile")
S3method("getUnitNames", "DChipCdfBinFile")
S3method("getUnitNamesFile", "AffymetrixCdfFile")
S3method("getUnitNamesFile", "AffymetrixCelFile")
S3method("getUnitNamesFile", "AffymetrixCelSet")
S3method("getUnitNamesFile", "AffymetrixCnChpFile")
S3method("getUnitNamesFile", "AffymetrixPgfFile")
S3method("getUnitNamesFile", "AffymetrixPlatform")
S3method("getUnitNamesFile", "TransformReport")
S3method("getUnitReadMap", "AffymetrixCnChpFile")
S3method("getUnitSizes", "DChipCdfBinFile")
S3method("getUnitTypes", "AffymetrixCdfFile")
S3method("getUnitTypesFile", "AffymetrixCdfFile")
S3method("getUnitTypesFile", "AffymetrixCelFile")
S3method("getUnitTypesFile", "AffymetrixCelSet")
S3method("getUnitTypesFile", "AffymetrixCnChpFile")
S3method("getUnitTypesFile", "AffymetrixPlatform")
S3method("getUnitTypesFile", "TransformReport")
S3method("getUnitsOnChromosome", "GenomeInformation")
S3method("getUnitsOnChromosome", "UgpGenomeInformation")
S3method("getUnitsOnChromosomes", "GenomeInformation")
S3method("getUnitsTo", "ProbeLevelTransform3")
S3method("getUnitsToFit", "CrlmmModel")
S3method("getUnitsToFit", "ProbeLevelTransform3")
S3method("getUnitsToUpdate", "ProbeLevelTransform3")
S3method("getWeights", "QualityAssessmentModel")
S3method("getWeightsFileClass", "WeightsSet")
S3method("getWeightsSet", "ProbeLevelModel")
S3method("getWeightsSetClass", "ProbeLevelModel")
S3method("getXAM", "ChipEffectFile")
S3method("getXAM", "ChipEffectSet")
S3method("getYY", "TransformReport")
S3method("groupUnitsByDimension", "AffymetrixCdfFile")
S3method("hasAlleleBFractions", "CnChipEffectFile")
S3method("hasAlleleBFractions", "CnChipEffectSet")
S3method("hasAlleleBFractions", "CnChipEffectSetTuple")
S3method("hasColumnHeader", "AffymetrixProbeTabFile")
S3method("hasMbeiData", "DChipDcpFile")
S3method("hasNormalizedData", "DChipDcpFile")
S3method("hasStrandiness", "CnChipEffectFile")
S3method("hasStrandiness", "CnChipEffectSet")
S3method("hasStrandiness", "CnChipEffectSetTuple")
S3method("hasUnitReadMap", "AffymetrixCnChpFile")
S3method("hasUnitTypes", "AffymetrixCdfFile")
S3method("highlight", "AffymetrixCelFile")
S3method("identifyCells", "AffymetrixCdfFile")
S3method("image270", "AffymetrixCelFile")
S3method("importFrom", "AromaUnitTabularBinaryFile")
S3method("importFromAffymetrixNetAffxCsvFile", "AromaUflFile")
S3method("importFromAffymetrixNetAffxCsvFile", "AromaUgpFile")
S3method("importFromAffymetrixNetAffxCsvFile", "AromaUnitGcContentFile")
S3method("importFromAffymetrixNetAffxCsvFile", "AromaUnitTabularBinaryFile")
S3method("importFromAffymetrixProbeTabFile", "AromaCellSequenceFile")
S3method("importFromAffymetrixTabularFile", "AromaUfcFile")
S3method("importFromAffymetrixTabularFile", "AromaUgpFile")
S3method("importFromAffymetrixTabularFile", "AromaUnitTabularBinaryFile")
S3method("importFromApt", "CnChipEffectSet")
S3method("importFromBpMap", "AromaCellMatchScoreFile")
S3method("importFromBpMap", "AromaCellSequenceFile")
S3method("importFromDChip", "AffymetrixCelSet")
S3method("importFromDChip", "CnChipEffectSet")
S3method("importFromDChipGenomeInformation", "AromaUnitTabularBinaryFile")
S3method("importFromGenericTabularFile", "AromaUnitTabularBinaryFile")
S3method("importFromGenomeInformation", "AromaUgpFile")
S3method("importFromGenomeInformation", "AromaUnitTabularBinaryFile")
S3method("indexOfMissingSequences", "AbstractProbeSequenceNormalization")
S3method("inferMmFromPm", "AromaCellSequenceFile")
S3method("inferParameters", "CnChipEffectSet")
S3method("inferParameters", "SnpChipEffectSet")
S3method("isCompatibleWithCdf", "GenomeInformation")
S3method("isCompatibleWithCdf", "SnpInformation")
S3method("isCompatibleWithCdf", "UflSnpInformation")
S3method("isCompatibleWithCdf", "UgpGenomeInformation")
S3method("isDuplicated", "AffymetrixCelSet")
S3method("isDuplicated", "CnagCfhSet")
S3method("isMissing", "AromaCellMatchScoreFile")
S3method("isMonocellCdf", "AffymetrixCdfFile")
S3method("isPm", "AffymetrixCdfFile")
S3method("isResequenceChip", "AffymetrixCdfFile")
S3method("isSnpChip", "AffymetrixCdfFile")
S3method("isUniqueCdf", "AffymetrixCdfFile")
S3method("isUnitGroupCellMap", "data.frame")
S3method("isUnitGroupCellMap", "default")
S3method("isUnitGroupCellMap", "matrix")
S3method("justRMA", "default")
S3method("justSNPRMA", "AffymetrixCelSet")
S3method("justSNPRMA", "character")
S3method("mapToUnitNamesFile", "DChipCdfBinFile")
S3method("mergeGroups", "ChipEffectFile")
S3method("mergeStrands", "CnChipEffectFile")
S3method("mergeStrands", "SnpChipEffectFile")
S3method("migrateTool", "CopyNumberSegmentationModel")
S3method("nbrOfArrays", "AffymetrixAptSummaryFile")
S3method("nbrOfArrays", "AffymetrixCelSet")
S3method("nbrOfArrays", "AffymetrixCelSetReporter")
S3method("nbrOfArrays", "AffymetrixCnChpSet")
S3method("nbrOfArrays", "CnagCfhSet")
S3method("nbrOfArrays", "DChipDcpSet")
S3method("nbrOfArrays", "QualityAssessmentModel")
S3method("nbrOfArrays", "TransformReport")
S3method("nbrOfCells", "AffymetrixCdfFile")
S3method("nbrOfCells", "AffymetrixCelFile")
S3method("nbrOfCells", "AffymetrixPgfFile")
S3method("nbrOfCells", "CnagCfhFile")
S3method("nbrOfCells", "DChipCdfBinFile")
S3method("nbrOfCells", "DChipDcpFile")
S3method("nbrOfCellsPerUnit", "AffymetrixCdfFile")
S3method("nbrOfCellsPerUnitGroup", "AffymetrixCdfFile")
S3method("nbrOfChipTypes", "ArrayExplorer")
S3method("nbrOfColumns", "AffymetrixCdfFile")
S3method("nbrOfColumns", "AffymetrixPgfFile")
S3method("nbrOfEnzymes", "AromaUfcFile")
S3method("nbrOfEnzymes", "SnpInformation")
S3method("nbrOfEnzymes", "UflSnpInformation")
S3method("nbrOfGroupsPerUnit", "AffymetrixCdfFile")
S3method("nbrOfQcUnits", "AffymetrixCdfFile")
S3method("nbrOfRows", "AffymetrixCdfFile")
S3method("nbrOfRows", "AffymetrixPgfFile")
S3method("nbrOfSnps", "AffymetrixCdfFile")
S3method("nbrOfSnps", "CnagCfhFile")
S3method("nbrOfSteps", "AromaPipeline")
S3method("nbrOfUnits", "AffymetrixCdfFile")
S3method("nbrOfUnits", "AffymetrixPgfFile")
S3method("nbrOfUnits", "DChipCdfBinFile")
S3method("nbrOfUnits", "DChipDcpFile")
S3method("nbrOfUnits", "GenomeInformation")
S3method("nbrOfUnits", "SnpInformation")
S3method("nbrOfUnits", "UflSnpInformation")
S3method("nbrOfUnits", "UgpGenomeInformation")
S3method("normalizeOneArrayVector", "FragmentEquivalentClassNormalization")
S3method("normalizeQuantile", "AffymetrixCelFile")
S3method("normalizeQuantile", "AffymetrixCelSet")
S3method("plotAllelePairs", "AllelicCrosstalkCalibration")
S3method("plotBasepair", "AllelicCrosstalkCalibration")
S3method("plotBoxplot", "ChipEffectSet")
S3method("plotBoxplotStats", "list")
S3method("plotCovariateEffects", "GcContentNormalization2")
S3method("plotDensity", "AffymetrixCelFile")
S3method("plotDensity", "AffymetrixCelSet")
S3method("plotDensity", "GenomeInformation")
S3method("plotImage", "AffymetrixCelFile")
S3method("plotMargins", "SpatialReporter")
S3method("plotMvsA", "AffymetrixCelFile")
S3method("plotMvsX", "AffymetrixCelFile")
S3method("plotNuse", "QualityAssessmentModel")
S3method("plotRle", "QualityAssessmentModel")
S3method("plotXYCurve", "TransformReport")
S3method("plotXYCurveLog2", "TransformReport")
S3method("predictOne", "AbstractProbeSequenceNormalization")
S3method("predictOne", "BaseCountNormalization")
S3method("predictOne", "LinearModelProbeSequenceNormalization")
S3method("predictOne", "MatNormalization")
S3method("process", "AbstractProbeSequenceNormalization")
S3method("process", "AdditiveCovariatesNormalization")
S3method("process", "AlleleSummation")
S3method("process", "AllelicCrosstalkCalibration")
S3method("process", "AromaPipeline")
S3method("process", "ArrayExplorer")
S3method("process", "BackgroundCorrection")
S3method("process", "ChipEffectGroupMerge")
S3method("process", "DChipQuantileNormalization")
S3method("process", "FragmentEquivalentClassNormalization")
S3method("process", "FragmentLengthNormalization")
S3method("process", "GcContentNormalization")
S3method("process", "GcRmaBackgroundCorrection")
S3method("process", "GenericReporter")
S3method("process", "LimmaBackgroundCorrection")
S3method("process", "MatNormalization")
S3method("process", "MatSmoothing")
S3method("process", "OpticalBackgroundCorrection")
S3method("process", "QuantileNormalization")
S3method("process", "ReseqCrosstalkCalibration")
S3method("process", "RmaBackgroundCorrection")
S3method("process", "ScaleNormalization")
S3method("process", "ScaleNormalization3")
S3method("process", "SpatialReporter")
S3method("process", "SpatialRowColumnNormalization")
S3method("process", "UnitTypeScaleNormalization")
S3method("range", "AffymetrixCelFile")
S3method("range", "AffymetrixCelSet")
S3method("range", "CnagCfhFile")
S3method("range", "CnagCfhSet")
S3method("read10K", "DChipSnpInformation")
S3method("read250K", "DChipSnpInformation")
S3method("read250KHg17", "DChipGenomeInformation")
S3method("read50K", "DChipSnpInformation")
S3method("read50KHg17", "DChipGenomeInformation")
S3method("readArrays", "AffymetrixAptSummaryFile")
S3method("readCfhHeader", "default")
S3method("readCfhUnits", "default")
S3method("readCfnHeader", "default")
S3method("readCfnUnits", "default")
S3method("readDataFrame", "AffymetrixCdfFile")
S3method("readDataFrame", "AffymetrixCsvGenomeInformation")
S3method("readDataFrame", "AffymetrixTsvFile")
S3method("readDataFrame", "AromaUfcFile")
S3method("readDataFrame", "DChipCdfBinFile")
S3method("readDataFrame", "DChipGenomeInformation")
S3method("readDataFrame", "DChipSnpInformation")
S3method("readDataFrame", "GenomeInformation")
S3method("readDataFrame", "SnpInformation")
S3method("readDataFrame", "UflSnpInformation")
S3method("readDataFrame", "UgpGenomeInformation")
S3method("readDataFrame2", "AffymetrixProbeTabFile")
S3method("readDataUnitChromosomePosition", "AffymetrixNetAffxCsvFile")
S3method("readDataUnitFragmentLength", "AffymetrixNetAffxCsvFile")
S3method("readGeneAssignments", "AffymetrixNetAffxCsvFile")
S3method("readGenomeWideSNP", "DChipGenomeInformation")
S3method("readHeader", "AffymetrixAptSummaryFile")
S3method("readMatchScores", "AromaCellMatchScoreFile")
S3method("readMouse430", "DChipGenomeInformation")
S3method("readMouse430KenHardwired", "DChipGenomeInformation")
S3method("readParameter", "CrlmmParametersFile")
S3method("readPlasqTypes", "AffymetrixCdfFile")
S3method("readPriorsByUnits", "MultiArrayUnitModel")
S3method("readProbesetIds", "AffymetrixAptSummaryFile")
S3method("readRawData", "AffymetrixCelFile")
S3method("readRawData", "AffymetrixCnChpFile")
S3method("readRawData", "AffymetrixPgfFile")
S3method("readRawDataRectangle", "AffymetrixCelFile")
S3method("readRawDataRectangle", "SpatialReporter")
S3method("readSequenceDataFrame", "AffymetrixProbeTabFile")
S3method("readTableInternal", "GenomeInformation")
S3method("readTableInternal", "SnpInformation")
S3method("readUnitNames", "AffymetrixNetAffxCsvFile")
S3method("readUnits", "AffymetrixCdfFile")
S3method("readUnits", "AffymetrixCelFile")
S3method("readUnits", "AffymetrixCelSet")
S3method("readUnits", "ChipEffectFile")
S3method("readUnits", "ChipEffectSet")
S3method("readUnits", "CnChipEffectFile")
S3method("readUnits", "CnagCfhFile")
S3method("readUnits", "CnagCfhSet")
S3method("readUnits", "ExonChipEffectFile")
S3method("readUnits", "FirmaFile")
S3method("readUnits", "FirmaSet")
S3method("readUnits", "MultiArrayUnitModel")
S3method("readUnits", "ParameterCelFile")
S3method("readUnits", "ProbeAffinityFile")
S3method("readUnits", "ResidualFile")
S3method("readUnits", "ResidualSet")
S3method("readUnits", "SingleArrayUnitModel")
S3method("readUnits", "SnpChipEffectFile")
S3method("readUnits", "WeightsFile")
S3method("readUnits", "WeightsSet")
S3method("readUnitsByQuartets", "AffymetrixCdfFile")
S3method("rescale", "AllelicCrosstalkCalibration")
S3method("rescaleByAll", "AllelicCrosstalkCalibration")
S3method("rescaleByAll", "ReseqCrosstalkCalibration")
S3method("rescaleByGroups", "AllelicCrosstalkCalibration")
S3method("restruct", "AffymetrixCdfFile")
S3method("seq", "TransformReport")
S3method("setAlias", "ArrayExplorer")
S3method("setAlias", "GenericReporter")
S3method("setAlias", "Model")
S3method("setAlias", "TransformReport")
S3method("setArrays", "ArrayExplorer")
S3method("setBandwidth", "SmoothMultiarrayModel")
S3method("setCdf", "AffymetrixCelFile")
S3method("setCdf", "AffymetrixCelSet")
S3method("setCdf", "AffymetrixCnChpFile")
S3method("setCdf", "AffymetrixCnChpSet")
S3method("setCdf", "CnagCfhFile")
S3method("setCdf", "CnagCfhSet")
S3method("setColorMaps", "ArrayExplorer")
S3method("setColorMaps", "SpatialReporter")
S3method("setCombineAlleles", "CnChipEffectSet")
S3method("setCombineAlleles", "CnPlm")
S3method("setCombineAlleles", "CnProbeAffinityFile")
S3method("setDecodeFunction", "ParameterCelFile")
S3method("setEncodeFunction", "ParameterCelFile")
S3method("setGenomeInformation", "AffymetrixCdfFile")
S3method("setLabel", "Model")
S3method("setListOfPriors", "MultiArrayUnitModel")
S3method("setMergeFunction", "ChipEffectGroupMerge")
S3method("setMergeGroups", "ExonChipEffectSet")
S3method("setMergeGroups", "ExonProbeAffinityFile")
S3method("setMergeGroups", "ExonRmaPlm")
S3method("setMergeStrands", "SnpChipEffectSet")
S3method("setMergeStrands", "SnpPlm")
S3method("setMergeStrands", "SnpProbeAffinityFile")
S3method("setReference", "SpatialReporter")
S3method("setRestructor", "AffymetrixCdfFile")
S3method("setSettings", "Package")
S3method("setSnpInformation", "AffymetrixCdfFile")
S3method("setTags", "Model")
S3method("setUnitReadMap", "AffymetrixCnChpFile")
S3method("setup", "GenericReporter")
S3method("setupExampleData", "AromaAffymetrix")
S3method("smoothScatterMvsA", "AffymetrixCelFile")
S3method("stextChipType", "AffymetrixCdfFile")
S3method("transformAffine", "AffymetrixCelFile")
S3method("transformAffine", "AffymetrixCelSet")
S3method("translateColumnNames", "AffymetrixAptSummaryFile")
S3method("translateColumnNames", "AffymetrixProbeTabFile")
S3method("translateColumnNames", "AffymetrixTabularFile")
S3method("translateFullName", "AffymetrixProbeTabFile")
S3method("update", "AromaAffymetrix")
S3method("update2", "AffymetrixCelSet")
S3method("updateDataFlat", "ChipEffectFile")
S3method("updateDataFlat", "FirmaFile")
S3method("updateDataFlat", "ResidualFile")
S3method("updateDataFlat", "WeightsFile")
S3method("updateMatchScores", "AromaCellMatchScoreFile")
S3method("updateParameter", "CrlmmParametersFile")
S3method("updateSampleAnnotationSet", "AffymetrixCelSet")
S3method("updateSettings", "Package")
S3method("updateSetupExplorerFile", "ArrayExplorer")
S3method("updateUnits", "AffymetrixCelFile")
S3method("updateUnits", "ChipEffectFile")
S3method("updateUnits", "ChipEffectSet")
S3method("updateUnits", "FirmaFile")
S3method("updateUnits", "FirmaSet")
S3method("updateUnits", "ParameterCelFile")
S3method("updateUnits", "ProbeAffinityFile")
S3method("updateUnits", "ResidualFile")
S3method("updateUnits", "ResidualSet")
S3method("updateUnits", "WeightsFile")
S3method("updateUnits", "WeightsSet")
S3method("validate", "AffymetrixCdfFile")
S3method("validate", "AvgPlm")
S3method("validate", "MultiArrayUnitModel")
S3method("verify", "AffymetrixCsvGenomeInformation")
S3method("verify", "AffymetrixTsvFile")
S3method("verify", "DChipGenomeInformation")
S3method("verify", "DChipSnpInformation")
S3method("verify", "GenomeInformation")
S3method("verify", "SnpInformation")
S3method("verify", "UflSnpInformation")
S3method("verify", "UgpGenomeInformation")
S3method("writeAsFullCelFile", "ChipEffectFile")
S3method("writeCNT", "SnpChipEffectFile")
S3method("writeCNT", "SnpChipEffectSet")
S3method("writeCdf", "AffyGenePDInfo")
S3method("writeCdf", "DBPDInfo")
S3method("writeCdf", "PDInfoList")
S3method("writeCdf", "default")
S3method("writeCdfByExcludingCells", "AffymetrixCdfFile")
S3method("writeImage", "AffymetrixCelFile")
S3method("writeImage", "ResidualFile")
S3method("writeImage", "WeightsFile")
S3method("writeImageCombined", "TransformReport")
S3method("writeImages", "SpatialReporter")
S3method("writeImages", "TransformReport")
S3method("writeRegions", "profileCGH")
S3method("writeSgr", "AffymetrixCelSet")
S3method("writeSignals", "ProbeLevelTransform3")
S3method("writeWig", "CnChipEffectSet")
