library("aroma.affymetrix")
log <- Arguments$getVerbose(-4, timestamp=TRUE)

dataSet <- "GSE8605"
chipType <- "Mapping10K_Xba142"

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Tests for setting up CEL sets and locating the CDF file
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
csR <- AffymetrixCelSet$byName(dataSet, chipType=chipType, verbose=log)
keep <- 1:6
csR <- csR[keep]
print(csR)


# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Allelic cross-talk calibration tests
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
acc <- AllelicCrosstalkCalibration(csR, flavor="expectile")
print(acc)

csC <- process(acc, verbose=log)
print(csC)

stopifnot(identical(getNames(csC), getNames(csR)))
